@@ -297,7 +297,7 @@ class SmartRegister:
 
     @staticmethod
     def autodiscover(
-        path: str | Path = '.',
+        path: str | Path = Path.cwd(),
         include: str = '',
         exclude: str = '',
     ) -> list[Path]:
@@ -608,10 +608,7 @@ class SmartRegister:
                     Log.register.debug("skipping '%s', name '%s' already exist", path, name)
                     continue
 
-                self(
-                    cls=maintype,
-                    name=name,
-                )
+                self(maintype)
                 registered.append(maintype)
 
         return registered
